@@ -1,4 +1,4 @@
-from spotpython.build.kriging import Kriging
+from spotpython.build import Kriging
 import numpy as np
 from math import erf
 from numpy import log, var
@@ -80,19 +80,19 @@ def test_optimize_model():
     n = 2
     p = 2
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
-    S.set_theta_values()
-    S.initialize_matrices()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
+    S._set_theta_values()
+    S._initialize_matrices()
     S.set_de_bounds()
     new_theta_p_Lambda = S.optimize_model()
     assert len(new_theta_p_Lambda) == n + p + 1
     # no noise, so Lambda is not considered
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=False)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
-    S.set_theta_values()
-    S.initialize_matrices()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
+    S._set_theta_values()
+    S._initialize_matrices()
     S.set_de_bounds()
     new_theta_p_Lambda = S.optimize_model()
     assert len(new_theta_p_Lambda) == n + p
@@ -104,10 +104,10 @@ def test_update_log():
     n = 2
     p = 2
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
-    S.set_theta_values()
-    S.initialize_matrices()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
+    S._set_theta_values()
+    S._initialize_matrices()
     S.set_de_bounds()
     _ = S.optimize_model()
     S.update_log()
@@ -132,11 +132,11 @@ def test_fit():
     assert len(S.log["negLnLike"]) == 1
 
 
-def test_initialize_variables():
+def test__initialize_variables():
     nat_X = np.array([[1, 2], [3, 4]])
     nat_y = np.array([1, 2])
     S = Kriging()
-    S.initialize_variables(nat_X, nat_y)
+    S._initialize_variables(nat_X, nat_y)
     assert S.nat_X.all() == nat_X.all()
     assert S.nat_y.all() == nat_y.all()
     assert S.nat_X.shape == (2, 2)
@@ -149,8 +149,8 @@ def test_set_variable_types():
     n = 2
     p = 2
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
     assert S.var_type == ["num", "num"]
     assert S.var_type == ["num", "num"]
     assert S.num_mask.all()
@@ -162,8 +162,8 @@ def test_set_variable_types():
     n = 3
     p = 1
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
     S.var_type
     assert S.var_type == ["num", "num", "num"]
 
@@ -174,9 +174,9 @@ def set_theta_values():
     n = 2
     p = 2
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
-    S.set_theta_values()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
+    S._set_theta_values()
     assert S.theta.all() == np.array([0.0, 0.0]).all()
     nat_X = np.array([[1, 2], [3, 4]])
     nat_y = np.array([1, 2])
@@ -184,10 +184,10 @@ def set_theta_values():
     n = 3
     p = 2
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
     snt = S.n_theta
-    S.set_theta_values()
+    S._set_theta_values()
     # since snt == 3, it is not equal to S.n_theta, which is 2 because
     # of the correction in the set_theta_values method
     assert S.n_theta != snt
@@ -199,10 +199,10 @@ def test_initialize_matrices():
     n = 3
     p = 1
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
-    S.set_theta_values()
-    S.initialize_matrices()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
+    S._set_theta_values()
+    S._initialize_matrices()
     # if var(self.nat_y) is > 0, then self.pen_val = self.n * log(var(self.nat_y)) + 1e4
     # else self.pen_val = self.n * var(self.nat_y) + 1e4
     assert S.pen_val == nat_X.shape[0] * log(var(S.nat_y)) + 1e4
@@ -213,10 +213,10 @@ def test_initialize_matrices():
     n = 3
     p = 1
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
-    S.set_theta_values()
-    S.initialize_matrices()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
+    S._set_theta_values()
+    S._initialize_matrices()
     # if var(self.nat_y) is > 0, then self.pen_val = self.n * log(var(self.nat_y)) + 1e4
     # else self.pen_val = self.n * var(self.nat_y) + 1e4
     assert S.pen_val == nat_X.shape[0] * (var(S.nat_y)) + 1e4
@@ -232,10 +232,10 @@ def test_fun_likelihood():
     n = 1
     p = 1
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=False)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
-    S.set_theta_values()
-    S.initialize_matrices()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
+    S._set_theta_values()
+    S._initialize_matrices()
     S.set_de_bounds()
     new_theta_p_Lambda = S.optimize_model()
     S.extract_from_bounds(new_theta_p_Lambda)
@@ -250,10 +250,10 @@ def test_likelihood():
     n = 2
     p = 1
     S = Kriging(name="kriging", seed=124, n_theta=n, n_p=p, optim_p=True, noise=False, theta_init_zero=True)
-    S.initialize_variables(nat_X, nat_y)
-    S.set_variable_types()
-    S.set_theta_values()
-    S.initialize_matrices()
+    S._initialize_variables(nat_X, nat_y)
+    S._set_variable_types()
+    S._set_theta_values()
+    S._initialize_matrices()
     S.build_Psi()
     S.build_U()
     S.likelihood()
